Gnat.Handshake (gnat v1.3.0-rc0) View Source

This module provides a single function which handles all of the variations of establishing a connection to a nats server and just returns {:ok, socket} or {:error, reason}

Link to this section Summary

Link to this section Functions